%global debug_package %{nil}
%global provider github
%global provider_tld com
%global project containerd
%global repo containerd
%global import_path %{provider}.%{provider_tld}/%{project}/%{repo}

#debuginfo not supported with Go
%global gopath  %{_libdir}/golang
%define gosrc %{gopath}/src/pkg/%{import_path}

Name:           docker-%{repo}
Version:        1.6.21
Release:        %mkrel 1
Summary:        A daemon to control runC
License:        ASL 2.0
Group:	        System/Configuration

URL:            https://www.docker.com/
Source0:        https://%{import_path}/archive/v%{version}.tar.gz

BuildRequires:  gcc
BuildRequires:  glibc-static-devel
# ensure build uses golang 1.4 or above
BuildRequires:  golang >= 1.4
BuildRequires:  golang-github-cpuguy83-md2man
BuildRequires:  compat-golang-github-cpuguy83-md2man-2-devel
BuildRequires:  golang-github-urfave-cli-devel
BuildRequires:  golang-github-urfave-cli-2-devel
BuildRequires:  golang-github-matttproud-protobuf-extensions-devel
BuildRequires:  golang-github-google-uuid-devel
BuildRequires:  golang-github-beorn7-perks-devel
BuildRequires:  golang-github-cespare-xxhash-devel
BuildRequires:  compat-golang-github-cespare-xxhash-2-devel
BuildRequires:  golang-github-mrunalp-fileutils
BuildRequires:  docker-devel
BuildRequires:  golang-github-coreos-systemd-devel
BuildRequires:  golang-etcd-bbolt-devel
BuildRequires:  git
BuildRequires:  btrfs-devel
BuildRequires:  pkgconfig(libseccomp)
Requires:		opencontainers-runc >= 1.0.0rc5

%description
containerd is a daemon to control runC, built for performance and density. 

containerd leverages runC's advanced features such as seccomp and user 
namespace support as well as checkpoint and restore for cloning and 
live migration of containers.

%prep
%setup -q -n %{repo}-%{version}
# Remove git usage as we're building off Internet
perl -pi -e 's|VERSION \?=.*|VERSION=%{version}|' Makefile
perl -pi -e 's|REVISION=.*|REVISION=%{release}|' Makefile
perl -pi -e 's|run -mod=readonly |run -mod=vendor|' Makefile
perl -pi -e 's|^GO_BUILD_FLAGS=.*|GO_BUILD_FLAGS="-mod=vendor"|' Makefile
mkdir -p src/%{provider}.%{provider_tld}/%{project}
ln -s $(pwd) src/%{import_path}
# Align with docker
find . -type f -print0 | xargs -0 perl -pi -e 's|/run/containerd|/run/docker/containerd|g'

%build
# Force module usage with vendor provided ones
export GO111MODULE=on
# Non vendor modules are there
export GOPATH=%{_datadir}/gocode
# We need it to avoid writing cache under $GOPATH
mkdir -p $(pwd)/tmp
export GOMODCACHE=$(pwd)/tmp
cd src/%{import_path}
make PREFIX=%{_prefix}
make PREFIX=%{_prefix} man

%install
export GO111MODULE=on
mkdir -p %{buildroot}%{_bindir}
%make_install DESTDIR=%{buildroot} PREFIX=%{_prefix}

export GOMODCACHE=$(pwd)/tmp
cd src/%{import_path}
make DESTDIR=%{buildroot} PREFIX=%{_prefix} install-man

# prefix commands with docker as well
cd %{buildroot}%{_bindir}
for i in *; do
	ln -sf $i docker-$i
done

%files
%license LICENSE
%doc NOTICE *.md
%{_bindir}/*
%{_mandir}/*/*.xz


%changelog
* Thu Jul 06 2023 bcornec <bcornec> 1.6.21-1.mga8
+ Revision: 1963627
- Update to upstream docker-containerd 1.6.21 to fix CVE-2022-23471, CVE-2023-25153, and CVE-2023-25173 mga#31268
- Update to upstream docker-containerd 1.6.21 to fix CVE-2022-23471, CVE-2023-25153, and CVE-2023-25173 mga#31268
- Update sha1
- Update to upstream 1.6.14 to fix CVE-2022-23471 - mga#31268 - works with update of docker 20.10.22
- Update docker-containerd to upstream 1.5.13 to fix mga#30525
- Fix mga#30279 with upstream docker-containerd 1.5.11
- Update to upstream docker-containerd 1.5.10 to fix mga#30111
- Update to upstream docker-containerd 1.5.9 to fix mga#30050
- Update to upstream docker-containerd 1.5.8 fixes mga#29669
- Update src
- update to upstream docker-containerd 1.5.7
- Update docker-containerd to 1.4.4 upstream

* Thu Dec 03 2020 bcornec <bcornec> 1.4.3-2.mga8
+ Revision: 1652204
- Update to upstrea 1.4.3 containerd

* Sun Feb 16 2020 umeabot <umeabot> 1.2.8-2.mga8
+ Revision: 1530697
- Mageia 8 Mass Rebuild

* Wed Sep 04 2019 bcornec <bcornec> 1.2.8-1.mga8
+ Revision: 1437232
- update docker-containerd to upstream 1.2.8

* Mon May 06 2019 bcornec <bcornec> 1.2.5-2.mga7
+ Revision: 1396408
- Fix socket location for docker-ctr tool

* Sun Mar 17 2019 bcornec <bcornec> 1.2.5-1.mga7
+ Revision: 1378400
- update to upstream containerd 1.2.5

* Tue Oct 16 2018 bcornec <bcornec> 1.2.0-0.beta.2.2.mga7
+ Revision: 1320701
- Update to upstream docker-containerd 1.2 made by Joseph Wang joequant

* Sun Sep 23 2018 umeabot <umeabot> 0.2.8-2.mga7
+ Revision: 1297480
- Mageia 7 Mass Rebuild

* Fri May 12 2017 bcornec <bcornec> 0.2.8-1.mga7
+ Revision: 1100545
- Update to upstream 0.2.8 docker-containerd

* Sat Sep 24 2016 bcornec <bcornec> 0.2.3-1.mga6
+ Revision: 1055670
- Force a dep on the 1.0 branch of runc as the previous one doesn't work anymore
- Update docker-containerd to upstream 0.2.3

* Mon May 23 2016 bcornec <bcornec> 0.2.1-4.mga6
+ Revision: 1018009
- bump rel

* Mon May 23 2016 bcornec <bcornec> 0.2.1-3.mga6
+ Revision: 1018000
- remove restriction on arch

* Sun May 22 2016 bcornec <bcornec> 0.2.1-2.mga6
+ Revision: 1017693
- containerd requires runc

* Sun May 22 2016 bcornec <bcornec> 0.2.1-1.mga6
+ Revision: 1017668
- Create a package for docker-containerd which is now needed by docker >= 1.11
- Created package structure for docker-containerd.

